@@ -630,11 +630,26 @@ setMethod("deepcopy", signature(object ="gpuMatrix"),
               
               out <- switch(typeof(object),
                             "integer" = new("igpuMatrix",
-                                            address = cpp_deepcopy_gpuMatrix(object@address, 4L)),
+                                            address = cpp_deepcopy_gpuMatrix(object@address, 4L),
+                            								.context_index = object@.context_index,
+                            								.platform_index = object@.platform_index,
+                            								.platform = object@.platform,
+                            								.device_index = object@.device_index,
+                            								.device = object@.device),
                             "float" = new("fgpuMatrix", 
-                                          address = cpp_deepcopy_gpuMatrix(object@address, 6L)),
+                                          address = cpp_deepcopy_gpuMatrix(object@address, 6L),
+                            							.context_index = object@.context_index,
+                            							.platform_index = object@.platform_index,
+                            							.platform = object@.platform,
+                            							.device_index = object@.device_index,
+                            							.device = object@.device),
                             "double" = new("dgpuMatrix", 
-                                           address = cpp_deepcopy_gpuMatrix(object@address, 8L)),
+                                           address = cpp_deepcopy_gpuMatrix(object@address, 8L),
+                            							 .context_index = object@.context_index,
+                            							 .platform_index = object@.platform_index,
+                            							 .platform = object@.platform,
+                            							 .device_index = object@.device_index,
+                            							 .device = object@.device),
                             stop("unrecognized type")
                             )
               return(out)
@@ -691,15 +706,33 @@ setMethod("cbind2",
               ptr <- switch(typeof(x),
                             "integer" = {
                                 address <- cpp_cbind_gpuMatrix(x@address, y@address, 4L)
-                                new("igpuMatrix", address = address)
+                                new("igpuMatrix", 
+                                    address = address,
+                                    .context_index = x@.context_index,
+                                    .platform_index = x@.platform_index,
+                                    .platform = x@.platform,
+                                    .device_index = x@.device_index,
+                                    .device = x@.device)
                             },
                             "float" = {
                                 address <- cpp_cbind_gpuMatrix(x@address, y@address, 6L)
-                                new("fgpuMatrix", address = address)
+                                new("fgpuMatrix", 
+                                    address = address,
+                                    .context_index = x@.context_index,
+                                    .platform_index = x@.platform_index,
+                                    .platform = x@.platform,
+                                    .device_index = x@.device_index,
+                                    .device = x@.device)
                             },
                             "double" = {
                                 address <- cpp_cbind_gpuMatrix(x@address, y@address, 8L)
-                                new("dgpuMatrix", address = address)
+                                new("dgpuMatrix", 
+                                    address = address,
+                                    .context_index = x@.context_index,
+                                    .platform_index = x@.platform_index,
+                                    .platform = x@.platform,
+                                    .device_index = x@.device_index,
+                                    .device = x@.device)
                             },
                             stop("type not recognized")
               )
@@ -716,15 +749,33 @@ setMethod("cbind2",
               ptr <- switch(typeof(x),
                             "integer" = {
                                 address <- cpp_cbind_gpuMatrix(x@address, y@address, 4L)
-                                new("igpuMatrix", address = address)
+                                new("igpuMatrix", 
+                                    address = address,
+                                    .context_index = x@.context_index,
+                                    .platform_index = x@.platform_index,
+                                    .platform = x@.platform,
+                                    .device_index = x@.device_index,
+                                    .device = x@.device)
                             },
                             "float" = {
                                 address <- cpp_cbind_gpuMatrix(x@address, y@address, 6L)
-                                new("fgpuMatrix", address = address)
+                                new("fgpuMatrix", 
+                                    address = address,
+                                    .context_index = x@.context_index,
+                                    .platform_index = x@.platform_index,
+                                    .platform = x@.platform,
+                                    .device_index = x@.device_index,
+                                    .device = x@.device)
                             },
                             "double" = {
                                 address <- cpp_cbind_gpuMatrix(x@address, y@address, 8L)
-                                new("dgpuMatrix", address = address)
+                                new("dgpuMatrix", 
+                                    address = address,
+                                    .context_index = x@.context_index,
+                                    .platform_index = x@.platform_index,
+                                    .platform = x@.platform,
+                                    .device_index = x@.device_index,
+                                    .device = x@.device)
                             },
                             stop("type not recognized")
               )
@@ -741,15 +792,33 @@ setMethod("cbind2",
               ptr <- switch(typeof(x),
                             "integer" = {
                                 address <- cpp_cbind_gpuMatrix(x@address, y@address, 4L)
-                                new("igpuMatrix", address = address)
+                                new("igpuMatrix", 
+                                    address = address,
+                                    .context_index = x@.context_index,
+                                    .platform_index = x@.platform_index,
+                                    .platform = x@.platform,
+                                    .device_index = x@.device_index,
+                                    .device = x@.device)
                             },
                             "float" = {
                                 address <- cpp_cbind_gpuMatrix(x@address, y@address, 6L)
-                                new("fgpuMatrix", address = address)
+                                new("fgpuMatrix", 
+                                    address = address,
+                                    .context_index = x@.context_index,
+                                    .platform_index = x@.platform_index,
+                                    .platform = x@.platform,
+                                    .device_index = x@.device_index,
+                                    .device = x@.device)
                             },
                             "double" = {
                                 address <- cpp_cbind_gpuMatrix(x@address, y@address, 8L)
-                                new("dgpuMatrix", address = address)
+                                new("dgpuMatrix", 
+                                    address = address,
+                                    .context_index = x@.context_index,
+                                    .platform_index = x@.platform_index,
+                                    .platform = x@.platform,
+                                    .device_index = x@.device_index,
+                                    .device = x@.device)
                             },
                             stop("type not recognized")
               )
@@ -767,15 +836,33 @@ setMethod("rbind2",
               ptr <- switch(typeof(x),
                             "integer" = {
                                 address <- cpp_rbind_gpuMatrix(x@address, y@address, 4L)
-                                new("igpuMatrix", address = address)
+                                new("igpuMatrix", 
+                                    address = address,
+                                    .context_index = x@.context_index,
+                                    .platform_index = x@.platform_index,
+                                    .platform = x@.platform,
+                                    .device_index = x@.device_index,
+                                    .device = x@.device)
                             },
                             "float" = {
                                 address <- cpp_rbind_gpuMatrix(x@address, y@address, 6L)
-                                new("fgpuMatrix", address = address)
+                                new("fgpuMatrix", 
+                                    address = address,
+                                    .context_index = x@.context_index,
+                                    .platform_index = x@.platform_index,
+                                    .platform = x@.platform,
+                                    .device_index = x@.device_index,
+                                    .device = x@.device)
                             },
                             "double" = {
                                 address <- cpp_rbind_gpuMatrix(x@address, y@address, 8L)
-                                new("dgpuMatrix", address = address)
+                                new("dgpuMatrix", 
+                                    address = address,
+                                    .context_index = x@.context_index,
+                                    .platform_index = x@.platform_index,
+                                    .platform = x@.platform,
+                                    .device_index = x@.device_index,
+                                    .device = x@.device)
                             },
                             stop("type not recognized")
               )
@@ -792,15 +879,33 @@ setMethod("rbind2",
               ptr <- switch(typeof(x),
                             "integer" = {
                                 address <- cpp_rbind_gpuMatrix(x@address, y@address, 4L)
-                                new("igpuMatrix", address = address)
+                                new("igpuMatrix", 
+                                    address = address,
+                                    .context_index = x@.context_index,
+                                    .platform_index = x@.platform_index,
+                                    .platform = x@.platform,
+                                    .device_index = x@.device_index,
+                                    .device = x@.device)
                             },
                             "float" = {
                                 address <- cpp_rbind_gpuMatrix(x@address, y@address, 6L)
-                                new("fgpuMatrix", address = address)
+                                new("fgpuMatrix", 
+                                    address = address,
+                                    .context_index = x@.context_index,
+                                    .platform_index = x@.platform_index,
+                                    .platform = x@.platform,
+                                    .device_index = x@.device_index,
+                                    .device = x@.device)
                             },
                             "double" = {
                                 address <- cpp_rbind_gpuMatrix(x@address, y@address, 8L)
-                                new("dgpuMatrix", address = address)
+                                new("dgpuMatrix", 
+                                    address = address,
+                                    .context_index = x@.context_index,
+                                    .platform_index = x@.platform_index,
+                                    .platform = x@.platform,
+                                    .device_index = x@.device_index,
+                                    .device = x@.device)
                             },
                             stop("type not recognized")
               )
@@ -817,15 +922,33 @@ setMethod("rbind2",
               ptr <- switch(typeof(x),
                             "integer" = {
                                 address <- cpp_rbind_gpuMatrix(x@address, y@address, 4L)
-                                new("igpuMatrix", address = address)
+                                new("igpuMatrix", 
+                                    address = address,
+                                    .context_index = x@.context_index,
+                                    .platform_index = x@.platform_index,
+                                    .platform = x@.platform,
+                                    .device_index = x@.device_index,
+                                    .device = x@.device)
                             },
                             "float" = {
                                 address <- cpp_rbind_gpuMatrix(x@address, y@address, 6L)
-                                new("fgpuMatrix", address = address)
+                                new("fgpuMatrix", 
+                                    address = address,
+                                    .context_index = x@.context_index,
+                                    .platform_index = x@.platform_index,
+                                    .platform = x@.platform,
+                                    .device_index = x@.device_index,
+                                    .device = x@.device)
                             },
                             "double" = {
                                 address <- cpp_rbind_gpuMatrix(x@address, y@address, 8L)
-                                new("dgpuMatrix", address = address)
+                                new("dgpuMatrix", 
+                                    address = address,
+                                    .context_index = x@.context_index,
+                                    .platform_index = x@.platform_index,
+                                    .platform = x@.platform,
+                                    .device_index = x@.device_index,
+                                    .device = x@.device)
                             },
                             stop("type not recognized")
               )
