@@ -19,17 +19,20 @@ void cpp_gpuMatrix_igemm(SEXP ptrA_, SEXP ptrB_, SEXP ptrC_,
     std::string sourceCode = as<std::string>(sourceCode_);
     cl_device_type ocl_device;
     
-    #if defined(__APPLE__) || defined(__MACOSX)
-        #ifdef HAVE_OPENCL_CL2_HPP
-            std::vector<std::string> sourceCodeVec;
-            sourceCodeVec.push_back(sourceCode);
-        #endif
-    #else
-        #ifdef HAVE_CL_CL2_HPP
-            std::vector<std::string> sourceCodeVec;
-            sourceCodeVec.push_back(sourceCode);
-        #endif
-    #endif
+    Program::Sources sources;
+    sources.push_back({sourceCode.c_str(), sourceCode.length()});
+    
+//    #if defined(__APPLE__) || defined(__MACOSX)
+//        #ifdef HAVE_OPENCL_CL2_HPP
+//            std::vector<std::string> sourceCodeVec;
+//            sourceCodeVec.push_back(sourceCode);
+//        #endif
+//    #else
+//        #ifdef HAVE_CL_CL2_HPP
+//            std::vector<std::string> sourceCodeVec;
+//            sourceCodeVec.push_back(sourceCode);
+//        #endif
+//    #endif
     
     XPtr<dynEigenMat<int> > ptrA(ptrA_);
     XPtr<dynEigenMat<int> > ptrB(ptrB_);
@@ -52,6 +55,8 @@ void cpp_gpuMatrix_igemm(SEXP ptrA_, SEXP ptrB_, SEXP ptrC_,
         Eigen::OuterStride<>(refC.outerStride())
     );
     
+//    Rcout << "all objects initialized" << std::endl;
+    
     int Mdim = Am.cols();
     int Ndim = Bm.rows();
     int Pdim = Am.rows();
@@ -63,14 +68,18 @@ void cpp_gpuMatrix_igemm(SEXP ptrA_, SEXP ptrB_, SEXP ptrC_,
     
     // Get available platforms
     std::vector<Platform> platforms;
-    getPlatforms(platforms); // cl_helpers.hpp      
+    getPlatforms(platforms); // cl_helpers.hpp   
+    
+//    Rcout << "got platforms" << std::endl;
     
     // Select the default platform and create a context using this platform and the GPU
-    cl_context_properties cps[3] = {
+    cl_context_properties cps[] = {
         CL_CONTEXT_PLATFORM,
-        (cl_context_properties)(platforms[0])(),
+        reinterpret_cast<cl_context_properties>(platforms[0]()),
         0
     };
+    
+//    Rcout << "selected default platform" << std::endl;
 
     // need to conditionally do CL_DEVICE_TYPE_CPU
     if(device_type == 0){
@@ -81,7 +90,7 @@ void cpp_gpuMatrix_igemm(SEXP ptrA_, SEXP ptrB_, SEXP ptrC_,
     
     Context context = createContext(ocl_device, cps, err);
         
-//        std::cout << "Context Made" << std::endl;
+//    Rcout << "Context Made" << std::endl;
 
     // Get a list of devices on this platform
     std::vector<Device> devices = context.getInfo<CL_CONTEXT_DEVICES>();
@@ -90,39 +99,45 @@ void cpp_gpuMatrix_igemm(SEXP ptrA_, SEXP ptrB_, SEXP ptrC_,
         stop("No GPU devices found");
     }
         
-//        std::cout << "Devices Found" << std::endl;
+//    Rcout << "Device Found" << std::endl;
 
         
     // Create a command queue and use the first device
     CommandQueue queue = CommandQueue(context, devices[0], 0, &err);
+    
+//    Rcout << "Command Queue created" << std::endl;
 
     // Read source file - passed in by R wrapper function
-    #if defined(__APPLE__) || defined(__MACOSX)
-        #ifndef HAVE_OPENCL_CL2_HPP
-            int pl;
-            std::pair <const char*, int> sourcePair;
-            sourcePair = std::make_pair(sourceCode.c_str(), pl);
-            Program::Sources source(1, sourcePair);
-        #else
-            Program::Sources source(sourceCodeVec);
-        #endif
-    #else
-        #ifndef HAVE_CL_CL2_HPP
-            int pl;
-            std::pair <const char*, int> sourcePair;
-            sourcePair = std::make_pair(sourceCode.c_str(), pl);
-            Program::Sources source(1, sourcePair);
-        #else
-            Program::Sources source(sourceCodeVec);
-        #endif
-    #endif
+//    #if defined(__APPLE__) || defined(__MACOSX)
+//        #ifndef HAVE_OPENCL_CL2_HPP
+//            int pl;
+//            std::pair <const char*, int> sourcePair;
+//            sourcePair = std::make_pair(sourceCode.c_str(), pl);
+//            Program::Sources source(1, sourcePair);
+//        #else
+//            Program::Sources source(sourceCodeVec);
+//        #endif
+//    #else
+//        #ifndef HAVE_CL_CL2_HPP
+//            int pl;
+//            std::pair <const char*, int> sourcePair;
+//            sourcePair = std::make_pair(sourceCode.c_str(), pl);
+//            Program::Sources source(1, sourcePair);
+//        #else
+//            Program::Sources source(sourceCodeVec);
+//        #endif
+//    #endif
+//    
+//    Rcout << "found kernel" << std::endl;
 
     // Make program of the source code in the context
-    Program program = Program(context, source);
+    Program program = Program(context, sources);
     if (err != CL_SUCCESS)
     {
        stop("Error: Failed to create compute program!\n");
     }
+    
+//    Rcout << "Program created" << std::endl;
         
     // Build program for these specific devices
     try
@@ -140,7 +155,7 @@ void cpp_gpuMatrix_igemm(SEXP ptrA_, SEXP ptrB_, SEXP ptrC_,
         stop("program failed to build");
     }
         
-//        std::cout << "Program Built" << std::endl;
+//    Rcout << "Program Built" << std::endl;
         
     // Make kernel
     Kernel kernel(program, "iMatMult", &err);
@@ -153,16 +168,20 @@ void cpp_gpuMatrix_igemm(SEXP ptrA_, SEXP ptrB_, SEXP ptrC_,
         
         
 //        cl_int wgSize = kernel.getWorkGroupInfo(CL_KERNEL_PREFERRED_WORK_GROUP_SIZE_MULTIPLE);
-//        std::cout << "Kernel made" << std::endl;
+//    Rcout << "Kernel made" << std::endl;
 
     // Create memory buffers
     Buffer bufferA = Buffer(context, CL_MEM_READ_ONLY, szA * sizeof(int), NULL, &err);
     Buffer bufferB = Buffer(context, CL_MEM_READ_ONLY, szB * sizeof(int), NULL, &err);
     Buffer bufferC = Buffer(context, CL_MEM_WRITE_ONLY, szC * sizeof(int), NULL, &err);
+    
+//    Rcout << "Buffers initialized" << std::endl;
 
     // Copy lists A and B to the memory buffers
     queue.enqueueWriteBuffer(bufferA, CL_TRUE, 0, szA * sizeof(int), Am.data());
     queue.enqueueWriteBuffer(bufferB, CL_TRUE, 0, szB * sizeof(int), Bm.data());
+    
+//    Rcout << "Buffers written" << std::endl;
 
         // Set arguments to kernel
 //        NDRange localWorkSize = NDRange(16, 16);
@@ -177,6 +196,8 @@ void cpp_gpuMatrix_igemm(SEXP ptrA_, SEXP ptrB_, SEXP ptrC_,
     err = kernel.setArg(3, bufferA);
     err = kernel.setArg(4, bufferB);
     err = kernel.setArg(5, bufferC);
+    
+//    Rcout << "kenel args set" << std::endl;
 //        err = kernel.setArg(4, 16*sizeof(int), NULL);
         
 //        err = kernel.setArg(3, sizeof(int), &Mdim);
@@ -191,10 +212,12 @@ void cpp_gpuMatrix_igemm(SEXP ptrA_, SEXP ptrB_, SEXP ptrC_,
 //        err = queue.enqueueNDRangeKernel(kernel, NullRange, global, local);
     err = queue.enqueueNDRangeKernel(kernel, NullRange, 
                                     NDRange(Mdim, Ndim), NullRange);
-
+//    Rcout << "kernel completed" << std::endl;
 //        err = queue.enqueueNDRangeKernel(kernel, NullRange, global, NullRange);
         
     // Read buffer C into a local list        
     err = queue.enqueueReadBuffer(bufferC, CL_TRUE, 0, 
                                 szC * sizeof(int), Cm.data());
+                                
+//    Rcout << "Completed Buffer Read" << std::endl;
 }
